
FaceRecognitionService
^^^^^^^^^^^^^^^^^^^^^^


.. image:: https://img.shields.io/pypi/v/face_recognition_service.svg
   :target: https://img.shields.io/pypi/v/face_recognition_service.svg
   :alt: alt text


.. image:: https://img.shields.io/travis/kedpter/face_recognition_service.svg
   :target: https://img.shields.io/travis/kedpter/face_recognition_service.svg
   :alt: alt text


.. image:: https://readthedocs.org/projects/face_recognition_service/badge/?version=latest
   :target: https://readthedocs.org/projects/face_recognition_service/badge/?version=latest
   :alt: alt text


A face recognition service built upon https://github.com/ageitgey/face_recognition.

Install
^^^^^^^

.. code-block:: bash

   pip install face_recognition_service

Usage
^^^^^

Run server and open http://127.0.0.1:8080/ to see an example.
